const { env } = require('process')
const { URL } = require('url')

const { injectScript, computeDpcHash } = require('./inject_script')
const { logStatus } = require('./log')
const { removeAllHeaders } = require('./remove_headers')

// adding env var fallbacks allows us to build locally with the Netlify CLI
const { DEPLOY_PRIME_URL = 'https://deploy-preview-2--dpcbp.netlify.app' } = env

module.exports = {
  async onPostBuild({ constants: { CONFIG_PATH, PUBLISH_DIR }, utils }) {
    // only enable deploy preview commenting for deploy previews
    if (env.CONTEXT !== 'deploy-preview') {
      return
    }

    const dpcHash = computeDpcHash()
    if (!dpcHash) {
      return utils.build.failPlugin('Deploy preview commenting is currently only supported for GitHub repos')
    }

    const [modifiedHeaders, injectedScripts] = await Promise.all([
      removeAllHeaders({ PUBLISH_DIR, CONFIG_PATH }),
      injectScript({ dpcHash, PUBLISH_DIR }),
    ])

    logStatus({ modifiedHeaders, injectedScripts })
    showStatus(utils)
  },
}

const showStatus = function (utils) {
  const url = new URL(DEPLOY_PRIME_URL)
  const [subdomain] = url.hostname.split('.')
  const dpcURL = `https://netlify-dpc.netlify.app/${subdomain}/`

  utils.status.show({
    title: 'Deploy Preview Commenting enabled!',
    summary: `View and discuss at ${dpcURL}`,
  })
}
