const { readFile, writeFile } = require('fs')
const { promisify } = require('util')

const pathExists = require('path-exists')

const frameOptionsRegEx = /\n^\s*x-frame-options.*$/gim

const pReadFile = promisify(readFile)
const pWriteFile = promisify(writeFile)

// remove iframe security headers so DPC works
const removeAllHeaders = async function ({ PUBLISH_DIR, CONFIG_PATH }) {
  const modifiedHeaders = await Promise.all([removeHeaders(`${PUBLISH_DIR}/_headers`), removeHeaders(CONFIG_PATH)])
  return modifiedHeaders.filter(Boolean)
}

const removeHeaders = async (filePath) => {
  if (!(await pathExists(filePath))) {
    return
  }

  const headers = await pReadFile(filePath, 'utf-8')

  if (!frameOptionsRegEx.test(headers)) {
    return
  }

  const updatedContents = headers.replace(frameOptionsRegEx, '')

  await pWriteFile(filePath, updatedContents, 'utf-8')

  return { filePath, updatedContents }
}

module.exports = {
  removeAllHeaders,
}
